==> libprelude_0.9.24.1.orig.tar.gz: libprelude-0.9.24.1/libmissing/setsockopt.c <==
/* setsockopt.c --- wrappers for Windows setsockopt function

   Copyright (C) 2008-2009 Free Software Foundation, Inc.

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU Lesser General Public License as published by
   the Free Software Foundation; either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU Lesser General Public License for more details.

   You should have received a copy of the GNU Lesser General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */

/* Written by Paolo Bonzini */

#include <config.h>

#define WIN32_LEAN_AND_MEAN
/* Get winsock2.h. */
#include <sys/socket.h>

/* Get struct timeval. */
#include <sys/time.h>

/* Get set_winsock_errno, FD_TO_SOCKET etc. */
#include "w32sock.h"

#undef setsockopt

int
rpl_setsockopt (int fd, int level, int optname, const void *optval, socklen_t optlen)
{
  int r;
  SOCKET sock = FD_TO_SOCKET (fd);

  if (level == SOL_SOCKET && (optname == SO_RCVTIMEO || optname == SO_SNDTIMEO))
    {
      const struct timeval *tv = optval;
      int milliseconds = tv->tv_sec * 1000 + tv->tv_usec / 1000;
      r = setsockopt (sock, level, optname, &milliseconds, sizeof (int));
    }
  else
    {
      r = setsockopt (sock, level, optname, optval, optlen);
    }

  if (r < 0)
    set_winsock_errno ();

  return r;
}

==> libprelude_1.0.0.orig.tar.gz: libprelude-1.0.0/libmissing/setsockopt.c <==
/* setsockopt.c --- wrappers for Windows setsockopt function

   Copyright (C) 2008-2010 Free Software Foundation, Inc.

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU Lesser General Public License as published by
   the Free Software Foundation; either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU Lesser General Public License for more details.

   You should have received a copy of the GNU Lesser General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */

/* Written by Paolo Bonzini */

#include <config.h>

#define WIN32_LEAN_AND_MEAN
/* Get winsock2.h. */
#include <sys/socket.h>

/* Get struct timeval. */
#include <sys/time.h>

/* Get set_winsock_errno, FD_TO_SOCKET etc. */
#include "w32sock.h"

#undef setsockopt

int
rpl_setsockopt (int fd, int level, int optname, const void *optval, socklen_t optlen)
{
  int r;
  SOCKET sock = FD_TO_SOCKET (fd);

  if (level == SOL_SOCKET && (optname == SO_RCVTIMEO || optname == SO_SNDTIMEO))
    {
      const struct timeval *tv = optval;
      int milliseconds = tv->tv_sec * 1000 + tv->tv_usec / 1000;
      optval = &milliseconds;
      r = setsockopt (sock, level, optname, optval, sizeof (int));
    }
  else
    {
      r = setsockopt (sock, level, optname, optval, optlen);
    }

  if (r < 0)
    set_winsock_errno ();

  return r;
}
